# wifind

[![pypi version](https://img.shields.io/pypi/v/wifind)](https://pypi.org/project/wifind/) [![pypi downloads](https://img.shields.io/pypi/dw/wifind)](https://pypi.org/project/wifind/)

```wifind``` is a cli tool that performs wifi fingerprinting and detect your position based on access points around you.
